@@ -8,9 +8,9 @@ OC.L10N.register(
     "Cheers!" : "¡Saludos!",
     "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
+    "Description:" : "Descripción:",
     "Where:" : "Dónde:",
-    "Anniversary" : "Aniversario",
-    "Personal" : "Personal",
+    "Location:" : "Ubicación:",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -26,17 +26,21 @@ OC.L10N.register(
     "Deleted" : "Borrado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
+    "Deck" : "Deck",
     "Share link" : "Compartir liga",
-    "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
-    "or" : "o",
+    "Automatic ({timezone})" : "({timezone}) automática",
+    "Timezone" : "Zona horaria",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
-    "Show week numbers" : "Mostrar número de semana",
+    "or" : "o",
+    "General" : "General",
+    "Files" : "Archivo",
+    "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
     "to" : "para",
@@ -48,29 +52,35 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Update" : "Actualizar",
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
-    "Delete file" : "Borrar archivo",
+    "hours" : "horas",
+    "days" : "días",
+    "weeks" : "semanas",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Delete file" : "Borrar archivo",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
-    "Send email" : "Enviar correo electrónico",
-    "All day" : "Todo el día",
+    "Attendees" : "Asistentes",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
+    "Resources" : "Recursos",
     "available" : "disponible",
-    "More" : "Más",
+    "None" : "Ninguno",
     "Global" : "Global",
     "Subscribe" : "Suscribir",
-    "Details" : "Detalles",
-    "Attendees" : "Asistentes",
-    "Resources" : "Recursos",
+    "Personal" : "Personal",
+    "Edit event" : "Editar evento",
+    "All day" : "Todo el día",
     "Close" : "Cerrar",
+    "Title" : "Título",
+    "Participants" : "Participantes",
+    "Submit" : "Enviar",
+    "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
@@ -81,9 +91,9 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "Talk" : "Hablar",
-    "Mail" : "Correo",
-    "Birthday" : "Fecha de nacimiento",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Hidden" : "Oculto",
+    "can edit" : "puede editar",
+    "Show week numbers" : "Mostrar número de semana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
