@@ -112,7 +112,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Ni mogoče posodobiti koledarja",
     "Shared calendars" : "Koledarji v souporabi",
     "Deck" : "Deck",
-    "Hidden" : "Skrito",
     "Internal link" : "Notranja povezava",
     "A private link that can be used with external clients" : "Zasebna povezava, ki se lahko uporablja z zunanjimi odjemalci",
     "Copy internal link" : "Kopiraj krajevno povezavo",
@@ -135,12 +134,10 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Skupina)",
     "An error occurred while unsharing the calendar." : "Prišlo je do napake med onemogočanjem souporabe koledarja.",
     "An error occurred, unable to change the permission of the share." : "Prišlo je do napake; ni mogoče spremeniti dovoljenj souporabe.",
-    "can edit" : "lahko ureja",
     "Unshare with {displayName}" : "Odstrani souporabo z uporabnikom {displayName}",
     "Share with users or groups" : "Souporaba z uporabniki in skupinami",
     "No users or groups" : "Ni uporabnikov ali skupin",
     "Failed to save calendar name and color" : "Shranjevanje imena koledarja in barve je spodletelo",
-    "Calendar name …" : "Ime koledarja …",
     "Share calendar" : "Omogoči souporabo koledarja",
     "Unshare from me" : "Prekini souporabo",
     "Save" : "Shrani",
@@ -157,7 +154,7 @@ OC.L10N.register(
     "Invalid location selected" : "Izbrano je neveljavno mesto",
     "Attachments folder successfully saved." : "Mapa prilog je uspešno shranjena.",
     "Error on saving attachments folder." : "Napaka med shranjevanjem mape prilog",
-    "Default attachments location" : "Privzeto mesto prilog",
+    "Attachments folder" : "Mapa prilog",
     "{filename} could not be parsed" : "Datoteke {filename} ni mogoče razčleniti",
     "No valid files found, aborting import" : "Ni najdenih veljavnih datotek, uvoz bo preklican",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Uspešno je uvožen %n dogodek.","Uspešno sta uvožena %n dogodka.","Uspešno so uvoženi %n dogodki.","Uspešno je uvoženih %n dogodkov."],
@@ -187,20 +184,11 @@ OC.L10N.register(
     "Calendar settings" : "Nastavitve koledarja",
     "No reminder" : "Brez opomnika",
     "Failed to save default calendar" : "Shranjevanje privzetega koledarja je spodletelo",
-    "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
-    "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
     "General" : "Splošno",
-    "Personal availability settings" : "Nastavitve osebne dejavnosti",
-    "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
-    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
-    "Show tasks in calendar" : "Pokaži naloge v koledarju",
-    "Show weekends" : "Pokaži vikende",
-    "Show week numbers" : "Pokaži številke tednov",
+    "Appearance" : "Videz",
     "Editing" : "Urejanje",
-    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
     "Default reminder" : "Privzeti opomnik",
-    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "Files" : "Datoteke",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuti","{duration} minute","{duration} minut"],
     "0 minutes" : "0 minut",
     "_{duration} hour_::_{duration} hours_" : ["{duration} ura","{duration} uri","{duration} ure","{duration} ur"],
@@ -317,8 +305,6 @@ OC.L10N.register(
     "Decline" : "Zavrni",
     "Tentative" : "V usklajevanju",
     "No attendees yet" : "Ni še vpisanih udeležencev",
-    "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
-    "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
     "Attendees" : "Udeleženci",
     "Remove group" : "Odstrani skupino",
     "Remove attendee" : "Odstrani udeleženca",
@@ -381,6 +367,7 @@ OC.L10N.register(
     "Yes" : "Da",
     "No" : "Ne",
     "Maybe" : "Morda",
+    "None" : "Brez",
     "Create" : "Ustvari",
     "from {formattedDate}" : "od {formattedDate}",
     "to {formattedDate}" : "do {formattedDate}",
@@ -506,7 +493,6 @@ OC.L10N.register(
     "When shared show full event" : "V souporabi pokaži poln dogodek",
     "When shared show only busy" : "V souporabi pokaži le, da je zasedeno",
     "When shared hide this event" : "V souporabi skrij ta dogodek",
-    "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi.",
     "Add a location" : "Dodaj mesto ...",
     "Status" : "Stanje",
     "Confirmed" : "Potrjeno",
@@ -529,11 +515,28 @@ OC.L10N.register(
     "This is an event reminder." : "To je opomnik dogodka.",
     "Appointment not found" : "Sestanka ni mogoče najti",
     "User not found" : "Uporabnika ni mogoče najti",
+    "Hidden" : "Skrito",
+    "can edit" : "lahko ureja",
+    "Calendar name …" : "Ime koledarja …",
+    "Default attachments location" : "Privzeto mesto prilog",
     "Automatic ({detected})" : "Samodejno ({detected})",
     "Shortcut overview" : "Pregled tipkovnih bližnjic",
+    "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
+    "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
+    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
+    "Show tasks in calendar" : "Pokaži naloge v koledarju",
     "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
     "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
+    "Show weekends" : "Pokaži vikende",
+    "Show week numbers" : "Pokaži številke tednov",
     "Time increments" : "Časovno povečevanje",
-    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice"
+    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
+    "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
+    "Personal availability settings" : "Nastavitve osebne dejavnosti",
+    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
+    "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
+    "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
+    "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
